<?php

namespace Drupal\noreferrer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Implements a noreferrer Config form.
 */
class NoReferrerSettingsForm extends ConfigFormBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'noreferrer_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['noreferrer.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['link'] = [
      '#type'          => 'checkbox',
      '#title'         => $this->t('Add <code>rel="noreferrer"</code> to all non-whitelisted links'),
      '#default_value' => $this->config('noreferrer.settings')->get('link'),
      '#description'   => $this->t('If checked, the <code>rel="noreferrer"</code> attribute will be added to all non-whitelisted links generated by the theme layer.'),
    ];
    $form['whitelisted_domains'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Whitelisted domains'),
      '#default_value' => $this->config('noreferrer.settings')->get('whitelisted_domains'),
      '#description'   => $this->t('Enter a space-separated list of domains to which referrer URLs will be sent (e.g. <em>example.com example.org</em>). Links to all other domains will have a <code>rel="noreferrer"</code> attribute added.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('noreferrer.settings')
      ->set('link', $form_state->getValue('link'))
      ->set('whitelisted_domains', $form_state->getValue('whitelisted_domains'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
