<?php

namespace Drupal\noreferrer\Plugin\Filter;

use Drupal\filter\Plugin\FilterBase;
use Drupal\Component\Utility\Html;
use Drupal\Component\Utility\UrlHelper;
use Drupal\filter\FilterProcessResult;

/**
 * Provides a filter to apply the noreferrer attribute.
 *
 * @Filter(
 *   id = "noreferrer",
 *   title = @Translation("No referrer"),
 *   description = @Translation("Adds <code>rel=&quot;noreferrer&quot;</code> attribute to all non-whitelisted links."),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_TRANSFORM_IRREVERSIBLE
 * )
 */
class NoReferrerFilter extends FilterBase {

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode) {
    $modified = FALSE;
    $result = new FilterProcessResult($text);
    $html_dom = Html::load($text);
    $links = $html_dom->getElementsByTagName('a');
    foreach ($links as $link) {
      if (UrlHelper::isExternal($link->getAttribute('href')) && !noreferrer_is_whitelisted($link->getAttribute('href'))) {
        $rel = $link->getAttribute('rel');
        $rel .= $rel ? ' noreferrer' : 'noreferrer';
        $link->setAttribute('rel', $rel);
        $modified = TRUE;
      }
    }
    if ($modified) {
      $result->setProcessedText(Html::serialize($html_dom));
    }
    return $result;
  }

}
